==> Decompiler-0.0.42-sources.jar: net/covers1624/coffeegrinder/bytecode/insns/LdcNumber.java <==
package net.covers1624.coffeegrinder.bytecode.insns;

import net.covers1624.coffeegrinder.bytecode.InsnOpcode;
import net.covers1624.coffeegrinder.bytecode.InsnVisitor;
import net.covers1624.coffeegrinder.bytecode.Instruction;
import net.covers1624.coffeegrinder.type.AType;
import net.covers1624.coffeegrinder.type.IntegerConstantType;
import net.covers1624.coffeegrinder.type.PrimitiveType;

/**
 * Created by covers1624 on 6/10/22.
 */
public class LdcNumber extends LdcInsn {

    private final Number value;
    private final AType resultType;

    public LdcNumber(Number value) {
        super(InsnOpcode.LDC_NUMBER);
        this.value = value;
        if (value instanceof Double) {
            resultType = PrimitiveType.DOUBLE;
        } else if (value instanceof Float) {
            resultType = PrimitiveType.FLOAT;
        } else if (value instanceof Integer) {
            resultType = new IntegerConstantType((Integer) value);
        } else {
            assert value instanceof Long;
            resultType = PrimitiveType.LONG;
        }
    }

    @Override
    public AType getResultType() {
        return resultType;
    }

    @Override
    public <R, C> R accept(InsnVisitor<R, C> visitor, C ctx) {
        return visitor.visitLdcNumber(this, ctx);
    }

    @Override
    public Instruction copy() {
        return new LdcNumber(value);
    }

    @Override
    public Number getRawValue() {
        return value;
    }

    public Number getValue() {
        return value;
    }

    public int intValue() {
        assert value instanceof Integer;
        return value.intValue();
    }
}

==> Decompiler-0.0.48-sources.jar: net/covers1624/coffeegrinder/bytecode/insns/LdcNumber.java <==
package net.covers1624.coffeegrinder.bytecode.insns;

import net.covers1624.coffeegrinder.bytecode.InsnVisitor;
import net.covers1624.coffeegrinder.bytecode.Instruction;
import net.covers1624.coffeegrinder.type.AType;
import net.covers1624.coffeegrinder.type.IntegerConstantType;
import net.covers1624.coffeegrinder.type.PrimitiveType;

/**
 * Created by covers1624 on 6/10/22.
 */
public final class LdcNumber extends LdcInsn {

    private final Number value;
    private final AType resultType;

    public LdcNumber(Number value) {
        this.value = value;
        if (value instanceof Double) {
            resultType = PrimitiveType.DOUBLE;
        } else if (value instanceof Float) {
            resultType = PrimitiveType.FLOAT;
        } else if (value instanceof Integer) {
            resultType = new IntegerConstantType((Integer) value);
        } else {
            assert value instanceof Long;
            resultType = PrimitiveType.LONG;
        }
    }

    @Override
    public AType getResultType() {
        return resultType;
    }

    @Override
    public <R, C> R accept(InsnVisitor<R, C> visitor, C ctx) {
        return visitor.visitLdcNumber(this, ctx);
    }

    @Override
    public Instruction copy() {
        return new LdcNumber(value);
    }

    @Override
    public Number getRawValue() {
        return value;
    }

    public Number getValue() {
        return value;
    }

    public int intValue() {
        assert value instanceof Integer;
        return value.intValue();
    }
}
